@@ -37,8 +37,13 @@ mod bif_any;
 mod bif_before;
 mod bif_date;
 mod bif_date_time;
+mod bif_decimal;
+mod bif_even;
+mod bif_exp;
 mod bif_get_entries;
 mod bif_get_value;
+mod bif_insert_before;
+mod bif_log;
 mod bif_lower_case;
 mod bif_sort;
 mod bif_string;
